## A simple example with simulated data

# Load procedures
load("procedures.r")


## Generate baseline and treatment group samples of size n according to a very
## simple data generating process
n <- 1000

x1 <- rnorm(n)
x2 <- rnorm(n)
y <- x1 + x2 + rnorm(n)
dat.base <- data.frame(y,x1,x2)
weights.base <- rep(1,n)

x1 <- rnorm(n)
x2 <- x1 + rnorm(n)
y <- 2*x1 + .5*x2 + rnorm(n)
dat.treat <- data.frame(y,x1,x2)
weights.treat <- rep(1,n)


# Compute the full decomposition
dat <- list(NA)
dat[[1]] <- dat.base
dat[[2]] <- dat.treat

weights <- list(NA)
weights[[1]] <- weights.base
weights[[2]] <- weights.treat

set.seed(12345) # set seed to ensure constancy of results based on MC integration

out.table <- full.decomp(formula = y~x1+x2,
                         covariate = ~x1+x2,
                         dat = dat, weights = weights)
## Explanation of arguments of full.decomp:
#   formula: a standard formula object as used in R in connection with lm() or
#            glm() for example. Can include interactions and transformations of
#            the orginal data, e.g. y~x1+x2+I(x1^2)+x1:x2. This argument is used
#            to estimate the conditional CDF functions by Distributional Regression
# covariate: a simple right-hand-side of a formula objects that gives all the
#            variables used in the argument "formula", but ommits interaction terms
#            and transformations
# dat, weights: lists with to elements each, containing the data sets and vectors
#               of weights.

# Give a table with the results. NOTE: Results for the Gini do not make sense
# since the dependent variable takes negative values in this examples. The
# software does not check this. The Gini results can be ignored in this case.
round(out.table,3)

